# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class HubPortChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'hub_port_id': 'int',
        'hub_port_number': 'int',
        'hub_port_node': 'HubNodeChild'
    }

    attribute_map = {
        'hub_port_id': 'HubPortId',
        'hub_port_number': 'HubPortNumber',
        'hub_port_node': 'HubPortNode'
    }

    def __init__(self, hub_port_id=None, hub_port_number=None, hub_port_node=None):  # noqa: E501
        """HubPortChild - a model defined in Swagger"""  # noqa: E501
        self._hub_port_id = None
        self._hub_port_number = None
        self._hub_port_node = None
        self.discriminator = None
        self.hub_port_id = hub_port_id
        self.hub_port_number = hub_port_number
        if hub_port_node is not None:
            self.hub_port_node = hub_port_node

    @property
    def hub_port_id(self):
        """Gets the hub_port_id of this HubPortChild.  # noqa: E501


        :return: The hub_port_id of this HubPortChild.  # noqa: E501
        :rtype: int
        """
        return self._hub_port_id

    @hub_port_id.setter
    def hub_port_id(self, hub_port_id):
        """Sets the hub_port_id of this HubPortChild.


        :param hub_port_id: The hub_port_id of this HubPortChild.  # noqa: E501
        :type: int
        """
        if hub_port_id is None:
            raise ValueError("Invalid value for `hub_port_id`, must not be `None`")  # noqa: E501

        self._hub_port_id = hub_port_id

    @property
    def hub_port_number(self):
        """Gets the hub_port_number of this HubPortChild.  # noqa: E501


        :return: The hub_port_number of this HubPortChild.  # noqa: E501
        :rtype: int
        """
        return self._hub_port_number

    @hub_port_number.setter
    def hub_port_number(self, hub_port_number):
        """Sets the hub_port_number of this HubPortChild.


        :param hub_port_number: The hub_port_number of this HubPortChild.  # noqa: E501
        :type: int
        """
        if hub_port_number is None:
            raise ValueError("Invalid value for `hub_port_number`, must not be `None`")  # noqa: E501

        self._hub_port_number = hub_port_number

    @property
    def hub_port_node(self):
        """Gets the hub_port_node of this HubPortChild.  # noqa: E501


        :return: The hub_port_node of this HubPortChild.  # noqa: E501
        :rtype: HubNodeChild
        """
        return self._hub_port_node

    @hub_port_node.setter
    def hub_port_node(self, hub_port_node):
        """Sets the hub_port_node of this HubPortChild.


        :param hub_port_node: The hub_port_node of this HubPortChild.  # noqa: E501
        :type: HubNodeChild
        """

        self._hub_port_node = hub_port_node

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HubPortChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HubPortChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
