# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MoveFilesResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'destination_folder_id': 'str',
        'success_count': 'int',
        'error_count': 'int',
        'errors': 'list[FilesError]'
    }

    attribute_map = {
        'destination_folder_id': 'DestinationFolderId',
        'success_count': 'SuccessCount',
        'error_count': 'ErrorCount',
        'errors': 'Errors'
    }

    def __init__(self, destination_folder_id=None, success_count=None, error_count=None, errors=None):  # noqa: E501
        """MoveFilesResponse - a model defined in Swagger"""  # noqa: E501
        self._destination_folder_id = None
        self._success_count = None
        self._error_count = None
        self._errors = None
        self.discriminator = None
        self.destination_folder_id = destination_folder_id
        self.success_count = success_count
        self.error_count = error_count
        self.errors = errors

    @property
    def destination_folder_id(self):
        """Gets the destination_folder_id of this MoveFilesResponse.  # noqa: E501


        :return: The destination_folder_id of this MoveFilesResponse.  # noqa: E501
        :rtype: str
        """
        return self._destination_folder_id

    @destination_folder_id.setter
    def destination_folder_id(self, destination_folder_id):
        """Sets the destination_folder_id of this MoveFilesResponse.


        :param destination_folder_id: The destination_folder_id of this MoveFilesResponse.  # noqa: E501
        :type: str
        """
        if destination_folder_id is None:
            raise ValueError("Invalid value for `destination_folder_id`, must not be `None`")  # noqa: E501

        self._destination_folder_id = destination_folder_id

    @property
    def success_count(self):
        """Gets the success_count of this MoveFilesResponse.  # noqa: E501


        :return: The success_count of this MoveFilesResponse.  # noqa: E501
        :rtype: int
        """
        return self._success_count

    @success_count.setter
    def success_count(self, success_count):
        """Sets the success_count of this MoveFilesResponse.


        :param success_count: The success_count of this MoveFilesResponse.  # noqa: E501
        :type: int
        """
        if success_count is None:
            raise ValueError("Invalid value for `success_count`, must not be `None`")  # noqa: E501

        self._success_count = success_count

    @property
    def error_count(self):
        """Gets the error_count of this MoveFilesResponse.  # noqa: E501


        :return: The error_count of this MoveFilesResponse.  # noqa: E501
        :rtype: int
        """
        return self._error_count

    @error_count.setter
    def error_count(self, error_count):
        """Sets the error_count of this MoveFilesResponse.


        :param error_count: The error_count of this MoveFilesResponse.  # noqa: E501
        :type: int
        """
        if error_count is None:
            raise ValueError("Invalid value for `error_count`, must not be `None`")  # noqa: E501

        self._error_count = error_count

    @property
    def errors(self):
        """Gets the errors of this MoveFilesResponse.  # noqa: E501


        :return: The errors of this MoveFilesResponse.  # noqa: E501
        :rtype: list[FilesError]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this MoveFilesResponse.


        :param errors: The errors of this MoveFilesResponse.  # noqa: E501
        :type: list[FilesError]
        """
        if errors is None:
            raise ValueError("Invalid value for `errors`, must not be `None`")  # noqa: E501

        self._errors = errors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MoveFilesResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MoveFilesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
