# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PicturesModelV3(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'description': 'str',
        'name': 'str',
        'image_file_name': 'str',
        'thumbnail_file_name': 'str',
        'attachment': 'AttachmentModelV3'
    }

    attribute_map = {
        'id': 'Id',
        'description': 'Description',
        'name': 'Name',
        'image_file_name': 'ImageFileName',
        'thumbnail_file_name': 'ThumbnailFileName',
        'attachment': 'Attachment'
    }

    def __init__(self, id=None, description=None, name=None, image_file_name=None, thumbnail_file_name=None, attachment=None):  # noqa: E501
        """PicturesModelV3 - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._description = None
        self._name = None
        self._image_file_name = None
        self._thumbnail_file_name = None
        self._attachment = None
        self.discriminator = None
        self.id = id
        if description is not None:
            self.description = description
        if name is not None:
            self.name = name
        if image_file_name is not None:
            self.image_file_name = image_file_name
        if thumbnail_file_name is not None:
            self.thumbnail_file_name = thumbnail_file_name
        if attachment is not None:
            self.attachment = attachment

    @property
    def id(self):
        """Gets the id of this PicturesModelV3.  # noqa: E501


        :return: The id of this PicturesModelV3.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PicturesModelV3.


        :param id: The id of this PicturesModelV3.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def description(self):
        """Gets the description of this PicturesModelV3.  # noqa: E501


        :return: The description of this PicturesModelV3.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PicturesModelV3.


        :param description: The description of this PicturesModelV3.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def name(self):
        """Gets the name of this PicturesModelV3.  # noqa: E501


        :return: The name of this PicturesModelV3.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PicturesModelV3.


        :param name: The name of this PicturesModelV3.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def image_file_name(self):
        """Gets the image_file_name of this PicturesModelV3.  # noqa: E501


        :return: The image_file_name of this PicturesModelV3.  # noqa: E501
        :rtype: str
        """
        return self._image_file_name

    @image_file_name.setter
    def image_file_name(self, image_file_name):
        """Sets the image_file_name of this PicturesModelV3.


        :param image_file_name: The image_file_name of this PicturesModelV3.  # noqa: E501
        :type: str
        """

        self._image_file_name = image_file_name

    @property
    def thumbnail_file_name(self):
        """Gets the thumbnail_file_name of this PicturesModelV3.  # noqa: E501


        :return: The thumbnail_file_name of this PicturesModelV3.  # noqa: E501
        :rtype: str
        """
        return self._thumbnail_file_name

    @thumbnail_file_name.setter
    def thumbnail_file_name(self, thumbnail_file_name):
        """Sets the thumbnail_file_name of this PicturesModelV3.


        :param thumbnail_file_name: The thumbnail_file_name of this PicturesModelV3.  # noqa: E501
        :type: str
        """

        self._thumbnail_file_name = thumbnail_file_name

    @property
    def attachment(self):
        """Gets the attachment of this PicturesModelV3.  # noqa: E501


        :return: The attachment of this PicturesModelV3.  # noqa: E501
        :rtype: AttachmentModelV3
        """
        return self._attachment

    @attachment.setter
    def attachment(self, attachment):
        """Sets the attachment of this PicturesModelV3.


        :param attachment: The attachment of this PicturesModelV3.  # noqa: E501
        :type: AttachmentModelV3
        """

        self._attachment = attachment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PicturesModelV3, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PicturesModelV3):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
