# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DashboardWidgetRequestChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dashboard_widget_id': 'str',
        'dashboard_widget_row': 'int',
        'dashboard_widget_column': 'int',
        'dashboard_widget_height': 'int',
        'dashboard_widget_width': 'int'
    }

    attribute_map = {
        'dashboard_widget_id': 'DashboardWidgetId',
        'dashboard_widget_row': 'DashboardWidgetRow',
        'dashboard_widget_column': 'DashboardWidgetColumn',
        'dashboard_widget_height': 'DashboardWidgetHeight',
        'dashboard_widget_width': 'DashboardWidgetWidth'
    }

    def __init__(self, dashboard_widget_id=None, dashboard_widget_row=None, dashboard_widget_column=None, dashboard_widget_height=None, dashboard_widget_width=None):  # noqa: E501
        """DashboardWidgetRequestChild - a model defined in Swagger"""  # noqa: E501
        self._dashboard_widget_id = None
        self._dashboard_widget_row = None
        self._dashboard_widget_column = None
        self._dashboard_widget_height = None
        self._dashboard_widget_width = None
        self.discriminator = None
        self.dashboard_widget_id = dashboard_widget_id
        self.dashboard_widget_row = dashboard_widget_row
        self.dashboard_widget_column = dashboard_widget_column
        self.dashboard_widget_height = dashboard_widget_height
        self.dashboard_widget_width = dashboard_widget_width

    @property
    def dashboard_widget_id(self):
        """Gets the dashboard_widget_id of this DashboardWidgetRequestChild.  # noqa: E501


        :return: The dashboard_widget_id of this DashboardWidgetRequestChild.  # noqa: E501
        :rtype: str
        """
        return self._dashboard_widget_id

    @dashboard_widget_id.setter
    def dashboard_widget_id(self, dashboard_widget_id):
        """Sets the dashboard_widget_id of this DashboardWidgetRequestChild.


        :param dashboard_widget_id: The dashboard_widget_id of this DashboardWidgetRequestChild.  # noqa: E501
        :type: str
        """
        if dashboard_widget_id is None:
            raise ValueError("Invalid value for `dashboard_widget_id`, must not be `None`")  # noqa: E501

        self._dashboard_widget_id = dashboard_widget_id

    @property
    def dashboard_widget_row(self):
        """Gets the dashboard_widget_row of this DashboardWidgetRequestChild.  # noqa: E501


        :return: The dashboard_widget_row of this DashboardWidgetRequestChild.  # noqa: E501
        :rtype: int
        """
        return self._dashboard_widget_row

    @dashboard_widget_row.setter
    def dashboard_widget_row(self, dashboard_widget_row):
        """Sets the dashboard_widget_row of this DashboardWidgetRequestChild.


        :param dashboard_widget_row: The dashboard_widget_row of this DashboardWidgetRequestChild.  # noqa: E501
        :type: int
        """
        if dashboard_widget_row is None:
            raise ValueError("Invalid value for `dashboard_widget_row`, must not be `None`")  # noqa: E501

        self._dashboard_widget_row = dashboard_widget_row

    @property
    def dashboard_widget_column(self):
        """Gets the dashboard_widget_column of this DashboardWidgetRequestChild.  # noqa: E501


        :return: The dashboard_widget_column of this DashboardWidgetRequestChild.  # noqa: E501
        :rtype: int
        """
        return self._dashboard_widget_column

    @dashboard_widget_column.setter
    def dashboard_widget_column(self, dashboard_widget_column):
        """Sets the dashboard_widget_column of this DashboardWidgetRequestChild.


        :param dashboard_widget_column: The dashboard_widget_column of this DashboardWidgetRequestChild.  # noqa: E501
        :type: int
        """
        if dashboard_widget_column is None:
            raise ValueError("Invalid value for `dashboard_widget_column`, must not be `None`")  # noqa: E501

        self._dashboard_widget_column = dashboard_widget_column

    @property
    def dashboard_widget_height(self):
        """Gets the dashboard_widget_height of this DashboardWidgetRequestChild.  # noqa: E501


        :return: The dashboard_widget_height of this DashboardWidgetRequestChild.  # noqa: E501
        :rtype: int
        """
        return self._dashboard_widget_height

    @dashboard_widget_height.setter
    def dashboard_widget_height(self, dashboard_widget_height):
        """Sets the dashboard_widget_height of this DashboardWidgetRequestChild.


        :param dashboard_widget_height: The dashboard_widget_height of this DashboardWidgetRequestChild.  # noqa: E501
        :type: int
        """
        if dashboard_widget_height is None:
            raise ValueError("Invalid value for `dashboard_widget_height`, must not be `None`")  # noqa: E501

        self._dashboard_widget_height = dashboard_widget_height

    @property
    def dashboard_widget_width(self):
        """Gets the dashboard_widget_width of this DashboardWidgetRequestChild.  # noqa: E501


        :return: The dashboard_widget_width of this DashboardWidgetRequestChild.  # noqa: E501
        :rtype: int
        """
        return self._dashboard_widget_width

    @dashboard_widget_width.setter
    def dashboard_widget_width(self, dashboard_widget_width):
        """Sets the dashboard_widget_width of this DashboardWidgetRequestChild.


        :param dashboard_widget_width: The dashboard_widget_width of this DashboardWidgetRequestChild.  # noqa: E501
        :type: int
        """
        if dashboard_widget_width is None:
            raise ValueError("Invalid value for `dashboard_widget_width`, must not be `None`")  # noqa: E501

        self._dashboard_widget_width = dashboard_widget_width

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DashboardWidgetRequestChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DashboardWidgetRequestChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
